
ffind -- find files by name/filetype/auxtype/etc (EXTERNAL) [v1.2]

syntax:  ffind [<pathname>] [-n <string>] [-e] [-f <filetype>]
               [-x <integer>] [-o <string>] [-q] [-p] [-d] [-b y|n]
               [ -i y|n] [-s <integer>]

ex:      ffind .61 -n foo   --find pathnames of all files on volume
                              in slot 6, drive 1 with names containing
                              "foo"
         ffind . -fsys      --find all sys files in current directory
         ffind              --find all files on all volumes

'ffind' is a flexible command for locating files.  It is especially
useful if you have a lot of subdirectories, since it will look
inside any subdirectories it finds.

The various options can be combined in a large number of useful ways;
no attempt is made here to illustrate all the possible combinations.

pathname: Tells 'ffind' where to look.  If you leave this out, it
      looks on all the ProDOS volumes in your system.  Wildcards are
      not currently allowed.

  -n: Specifies a string which must be contained in a filename
      before 'ffind' will print it.  Example:  ffind -n copy
      finds all files having "copy" somewhere in their names.

  -e: Forces -n to find only exact matches (not files whose names
      merely *contain* the specified string).  [This option is
      meaningful only if you use -n.]

  -f: Tells 'ffind' what filetype to look for.  Example:
      ffind -fawp  finds AppleWorks Word Processor files.

  -x: Tells 'ffind' what auxiliary type to look for.  Example:
      ffind -fbin -x$800  finds binary files that load at $800.

  -b: Tells 'ffind' to look for files that have their "need
      backup" flag set (-by) or clear (-bn).  (The backup bit is
      displayed in 'cat' listings and by the 'info' command; it
      gets set whenever a file is changed, and you can clear it
      with the -b option of the 'copy', 'update', or 'touch'
      commands.)

  -d: 'ffind' normally prints detailed information on each
      match found, like this:

         filetype  auxtype last-modified-date pathname

      The -d option tells 'ffind' NOT to print this detailed
      information about each file.  (Note that earlier versions
      of 'ffind' defaulted to no detailed information, and the -d
      option forced its inclusion.)

  -q: Stands for "query"--forces 'ffind' to stop after every
      match and ask "Continue search? (y/n)"

  -p: Sets your prefix to the directory containing the last
      match found.

  -o: The string following "-o" will be printed for each pathname
      found, but the pathname found will be printed in place of any
      "=" characters in the string.  [This is useful for generating
      script files to be 'exec'ed later.  See 'help =' for more
      discussion, since the '=' command has a similar feature.]

  -i: Tells 'ffind' to look for files that have their "invisible"
      flag set (-iy) or clear (-in).  (The invisible flag is
      displayed in 'cat' listings (use -i to see invisible files)
      and by the 'info' command.  You can set or clear it with the
      -i option of the 'touch' command.)

  -s: Tells 'ffind' what storage type to look for.  Example:
      ffind -s5  finds all GS/OS "extended" files.  This might
      come in handy when copying lots of files, since Davex (and
      ProDOS 8) can't work with extended files.
